==> qtjambi-qt3drender-6.3.0-sources.jar: io/qt/qt3d/render/QTextureCubeMapArray.java <==
package io.qt.qt3d.render;


/**
 * <p>A QAbstractTexture with a TargetCubeMapArray target format</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qt3drender-qtexturecubemaparray.html">Qt3DRender::QTextureCubeMapArray</a></p>
 */
public class QTextureCubeMapArray extends io.qt.qt3d.render.QAbstractTexture
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QTextureCubeMapArray.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QTextureCubeMapArray(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QTextureCubeMapArray() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qtexturecubemaparray.html#QTextureCubeMapArray">Qt3DRender::QTextureCubeMapArray::QTextureCubeMapArray(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QTextureCubeMapArray(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QTextureCubeMapArray instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QTextureCubeMapArray(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QTextureCubeMapArray(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QTextureCubeMapArray instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3drender-6.4.0-sources.jar: io/qt/qt3d/render/QTextureCubeMapArray.java <==
package io.qt.qt3d.render;


/**
 * <p>A QAbstractTexture with a TargetCubeMapArray target format</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qt3drender-qtexturecubemaparray.html">Qt3DRender::QTextureCubeMapArray</a></p>
 */
public class QTextureCubeMapArray extends io.qt.qt3d.render.QAbstractTexture
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QTextureCubeMapArray.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QTextureCubeMapArray(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QTextureCubeMapArray() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qtexturecubemaparray.html#QTextureCubeMapArray">Qt3DRender::QTextureCubeMapArray::QTextureCubeMapArray(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QTextureCubeMapArray(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QTextureCubeMapArray instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QTextureCubeMapArray(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QTextureCubeMapArray(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QTextureCubeMapArray instance, QDeclarativeConstructor constructor);
    
}
